@@ -1,12 +1,13 @@
+/* $ID: spatialpack.h, last updated 2018/08/07, osorio */
+
 #ifndef SPATIALPACK_H
 #define SPATIALPACK_H
 
-#include "codisp_coef.h"
-#include "cor_spatial.h"
-#include "mod_ttest.h"
+#include "base.h"
 
-/* Routines to be called from R */
+/* routines to assess the correlation between two spatial processes (to be called from R) */
 extern void codisp(double *, double *, double *, double *, int *, double *, double *, double *);
+extern void codisp_direction(double *, double *, int *, int *, int *, double *);
 extern void cor_spatial(double *, double *, double *, double *, double *, double *, double *, int *, double *, double *);
 extern void modified_ttest(double *, double *, double *, double *, int *, double *, double *, double *, double *, double *);
 
